# DataCollectionForm

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**description** | **str** |  | [optional] 
**expired** | **bool** |  | [optional] 
**questions** | [**list[Question]**](Question.md) |  | [optional] 
**sender** | **str** |  | [optional] 
**title** | **str** |  | [optional] 
**total_answers** | **int** |  | [optional] 

[[Back to Model list]](README.md#documentation-for-models) [[Back to API list]](README.md#documentation-for-api-endpoints) [[Back to README]](README.md)


